CORD19kg API
============

:code:`cord19kg` package
---------------------------

The package contains a set of tools for interactive exploration and analysis of the CORD-19 dataset using the co-occurrence analysis of the extracted named entities. It includes data preparation and curation helpers, tools for generation and analysis of co-occurrence networks. Moreover, it provides several mini-applications (based on JupyterDash and ipywidgets) for Jupyter

* :ref:`utils_ref`
* :ref:`curation_app_ref`
* :ref:`visualization_app_ref`
* :ref:`topic_app_ref`

.. toctree::
   :hidden:

   modules/cord19kg_utils
   modules/curation_app_source
   modules/visualization_app_source
   modules/topic_apps_source

